datablock AudioProfile(TraceOnSound)
{
	filename = "./TraceOn.wav";
	description = AudioClosest3d;
	preload = false;
};
datablock AudioProfile(UBWSound)
{
	filename = "./UBW.wav";
	description = AudioClosest3d;
	preload = false;
};
datablock ItemData(ArcherArmItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./Garcher.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Arm of Archer";
	iconName = "./Archer_Icon";
	doColorShift = false;
	colorShiftColor = "0.25 0 0 1.000";

	 // Dynamic properties defined by the scripts
	image = ArcherArmImage;
	canDrop = true;
};
datablock ShapeBaseImageData(ArcherArmHandImage)
{
	shapeFile = "./Garcher.dts";
	emap = true;
	mountPoint = 0;
	eyeoffset = "0 0 0";
	offset = "0 0 0";
	rotation = eulerToMatrix("0 0 0");
	scale = "1 1 1";
	doColorShift = false;
};
datablock ShapeBaseImageData(ArcherArmImage)
{
	// Basic Item properties
	shapeFile = "base/data/shapes/empty.dts";
	emap = true;

	// Specify mount point & offset for 3rd person, and eye offset
	// for first person rendering.
	mountPoint = 0;
	offset = "0 0 0";
	eyeOffset = "0 0 0";
	rotation = eulerToMatrix( "0 0 0" );

	// When firing from a point offset from the eye, muzzle correction
	// will adjust the muzzle vector to point to the eye LOS point.
	// Since this weapon doesn't actually fire from the muzzle point,
	// we need to turn this off.  
	correctMuzzleVector = true;

	// Add the WeaponImage namespace as a parent, WeaponImage namespace
	// provides some hooks into the inventory system.
	className = "WeaponImage";

	// Projectile && Ammo.
	item = ArcherArmItem;
	ammo = " ";
	projectile = "";
	projectileType = Projectile;

	casing = "";
	shellExitDir        = "1.0 -1.3 1.0";
	shellExitOffset     = "0 0 0";
	shellExitVariance   = 15.0;	
	shellVelocity       = 7.0;

	//melee particles shoot from eye node for consistancy
	melee = false;
	//raise your arm up or not
	armReady = true;

	doColorShift = false;
	colorShiftColor = ArcherArmItem.colorShiftColor;//"0.400 0.196 0 1.000";

	//casing = " ";

	// Images have a state system which controls how the animations
	// are run, which sounds are played, script callbacks, etc. This
	// state system is downloaded to the client so that clients can
	// predict state changes and animate accordingly.  The following
	// system supports basic ready->fire->reload transitions as
	// well as a no-ammo->dryfire idle state.

	// Initial start up state
	stateName[0]					= "Activate";
	stateTimeoutValue[0]			= 0.15;
	stateTransitionOnTimeout[0]		= "Ready";
	stateScript[0]					= "onEquip";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]					= "Ready";
	stateTransitionOnTriggerDown[1]	= "Fire";
	stateAllowImageChange[1]		= true;
	stateSequence[1]				= "Ready";

	stateName[2]					= "Fire";
	stateTransitionOnTimeout[2]		= "Reload";
	stateTimeoutValue[2]			= 0.5;
	stateAllowImageChange[2]		= false;
	stateSequence[2]				= "Fire";
	stateScript[2]					= "onFire";
	stateWaitForTimeout[2]			= true;

	stateName[3]					= "Reload";
	stateSequence[3]				= "Reload";
	stateTransitionOnTriggerUp[3]	= "Ready";
	//stateSequence[3]	= "Ready";
};
package Archer {
	function serverCmdDropTool(%client,%slot) {
		%player = %client.player;
		if(isObject(%player)) {
			if(%player.traceOn) {
				cancel(%player.tracing);
				%player.stopTrace();
				return;
			} else {
				if(%player.isArcher) {
					%player.isArcher = false;
					%player.unHideNode($RHand[0]);
					%player.unMountImage(2);
				}
			}
		}
		parent::servercmdDropTool(%client,%slot);
	}
	function ArcherArmImage::onEquip(%this,%player,%slot) {
		%player.hideNode($RHand[0]);
		if(!%player.isArcher) {
			%player.playAudio(%slot,UBWSound);
			%player.mountImage(ArcherArmHandImage,2);
			%player.isArcher = true;
		} else {
			if(%player.traceOn) {
				%player.mountImage(%player.tracedImage,%slot);
			}
		}
	}
	function ArcherArmImage::onFire(%this,%player,%slot) {
		if(%player.getDamagePercent() < 1.0)
			%player.playThread(0, shiftAway);
		%eyepoint = %player.getEyePoint();
		%eyevector = %player.getEyeVector();
		%raycast = containerRaycast(%eyepoint,VectorAdd(%eyepoint,VectorScale(%eyevector,128)), $Typemasks::PlayerObjectType,%player);
		%hit = getWord(%raycast,0);
		if(isObject(%hit) && isObject(%hit.getMountedImage(0))) {
			%player.playAudio(%slot,TraceOnSound);
			%image = %hit.getMountedImage(0).getID();
			if(%image != ArcherArmImage.getID()) {
				%player.mountImage(%image,0);
				%player.traceOn = true;
				%player.tracedImage = %image;
				%player.tracing = %player.schedule(10000,stopTrace);
				if(!%player.client.hasTracedBefore){
					%player.client.chatMessage("\c4You have traced an item. Drop it to trace another.");
					%player.client.hasTracedBefore = true;
				}
			}
		}
	}
	function player::stopTrace(%player) {
		%player.traceOn = false;
		if(%player.getMountedImage(0).getID() == %player.tracedImage) {
			%player.playThread(1, root);
			%player.playThread(1, armreadyright);
			%player.mountImage(ArcherArmImage,0);
		}
	}
};
activatepackage(Archer);